'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _core = require('@material-ui/core');

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// This is the only format accepted by the TextField native datepicker.
var DATE_PICKER_FORMAT = 'YYYY-MM-DD';

// Fix for OCEMCM-16564 - year field to accept only 4 char.
var MAX_DATE = '9999-12-31';

var formatDateToDatePickerString = function formatDateToDatePickerString(dateObject) {
  return (0, _moment2.default)(dateObject).format(DATE_PICKER_FORMAT);
};

var DatePicker = function DatePicker(_ref) {
  var disabled = _ref.disabled,
      label = _ref.label,
      minDate = _ref.minDate,
      _ref$maxDate = _ref.maxDate,
      maxDate = _ref$maxDate === undefined ? MAX_DATE : _ref$maxDate,
      required = _ref.required,
      showError = _ref.showError,
      _ref$input = _ref.input,
      value = _ref$input.value,
      onChange = _ref$input.onChange,
      _onBlur = _ref$input.onBlur,
      _ref$meta = _ref.meta,
      touched = _ref$meta.touched,
      error = _ref$meta.error,
      _ref$margin = _ref.margin,
      margin = _ref$margin === undefined ? 'normal' : _ref$margin;

  var datePickerValue = value && formatDateToDatePickerString(value);
  var min = minDate && formatDateToDatePickerString(minDate);
  var max = maxDate && formatDateToDatePickerString(maxDate);

  var handleChange = function handleChange(event) {
    // Convert from DATE_PICKER_FORMAT to Date object for redux-form field value.
    // Need to use moment because new Date() would shift a day when coming back
    // in with formatDateToDatePickerString()
    //   moment("2017-09-30").toDate() => Wed Sep 30 2017 00:00:00 GMT-0700 (PDT)
    //   new Date("2017-09-30") => Tue Sep 29 2017 17:00:00 GMT-0700 (PDT)
    onChange((0, _moment2.default)(event.target.value).toDate());
  };

  return _react2.default.createElement(_core.TextField, {
    disabled: disabled,
    error: (showError || touched) && !!error,
    fullWidth: true,
    helperText: (showError || touched) && error,
    InputProps: { inputProps: { min: min, max: max } },
    InputLabelProps: { shrink: true },
    label: label,
    margin: margin,
    onChange: handleChange,
    required: required,
    type: 'date',
    value: datePickerValue,
    onBlur: function onBlur() {
      return _onBlur && _onBlur();
    }
  });
};

DatePicker.displayName = 'DatePicker';

DatePicker.propTypes = {
  disabled: _propTypes2.default.bool,
  label: _propTypes2.default.string,
  minDate: _propTypes2.default.object, // Date object
  maxDate: _propTypes2.default.object, // Date object
  required: _propTypes2.default.bool,
  // redux-form props
  input: _propTypes2.default.object,
  meta: _propTypes2.default.object
};

exports.default = DatePicker;