'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _MenuItem = require('@material-ui/core/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _TextField = require('@material-ui/core/TextField');

var _TextField2 = _interopRequireDefault(_TextField);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// SelectField will show 5.5 menu items by default. Scrollbar will auto-show
// if there are more items.
var VISIBLE_MENU_ITEM_COUNT = 5.5;

// Hardcoded values from material-ui source
var MUI_MENU_ITEM_HEIGHT = 32;
var MUI_MENU_PADDING_TOP = 8;

var maxHeight = MUI_MENU_ITEM_HEIGHT * VISIBLE_MENU_ITEM_COUNT + MUI_MENU_PADDING_TOP;
var MenuProps = { PaperProps: { style: { maxHeight: maxHeight } } };

var SelectField = function SelectField(_ref) {
  var className = _ref.className,
      disabled = _ref.disabled,
      helperText = _ref.helperText,
      items = _ref.items,
      label = _ref.label,
      multiple = _ref.multiple,
      required = _ref.required,
      displayEmpty = _ref.displayEmpty,
      _ref$input = _ref.input,
      name = _ref$input.name,
      value = _ref$input.value,
      _onBlur = _ref$input.onBlur,
      _onChange = _ref$input.onChange,
      _ref$meta = _ref.meta;
  _ref$meta = _ref$meta === undefined ? {} : _ref$meta;
  var touched = _ref$meta.touched,
      error = _ref$meta.error;

  var hasError = touched && !!error;
  var hasHelperText = !!helperText;
  var separator = hasError && hasHelperText && ' | ' || '';
  var combinedHelperText = (hasError || hasHelperText) && _react2.default.createElement(
    'span',
    null,
    hasError && error,
    separator,
    hasHelperText && helperText
  );

  return _react2.default.createElement(
    _TextField2.default,
    {
      select: true,
      id: name,
      value: value,
      label: label,
      className: className,
      disabled: disabled,
      error: hasError,
      fullWidth: true,
      margin: 'normal',
      required: required,
      helperText: combinedHelperText,
      SelectProps: { MenuProps: MenuProps, multiple: multiple, displayEmpty: displayEmpty },
      onBlur: function onBlur(event) {
        return _onBlur && _onBlur(event.target.value);
      },
      onChange: function onChange(event) {
        return _onChange(event.target.value);
      }
    },
    items && items.map(function (item) {
      return _react2.default.createElement(
        _MenuItem2.default,
        { key: item.value, value: item.value },
        item.label
      );
    })
  );
};

SelectField.propTypes = {
  input: _propTypes2.default.shape({
    value: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number, _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]))]),
    onChange: _propTypes2.default.func.isRequired
  }).isRequired,
  items: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    value: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
    label: _propTypes2.default.string
  })).isRequired
};

SelectField.displayName = 'SelectField';

exports.default = SelectField;