'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createApiActionTypes = exports.API_FAILURE = exports.API_SUCCESS = exports.API_REQUEST = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _ramda = require('ramda');

var _reduxApiMiddleware = require('redux-api-middleware');

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var API_REQUEST = exports.API_REQUEST = 'API_REQUEST';
var API_SUCCESS = exports.API_SUCCESS = 'API_SUCCESS';
var API_FAILURE = exports.API_FAILURE = 'API_FAILURE';

var mergePlan = function mergePlan(x, y) {
  if (Array.isArray(x) && Array.isArray(y)) {
    return (0, _ramda.uniq)((0, _ramda.concat)(x, y));
  }

  if ((typeof x === 'undefined' ? 'undefined' : _typeof(x)) === 'object' && (typeof y === 'undefined' ? 'undefined' : _typeof(y)) === 'object') {
    return (0, _ramda.mergeWith)(mergePlan, x, y);
  }

  return y;
};

var deepMerge = (0, _ramda.mergeWith)(mergePlan);

var createApiActionTypes = exports.createApiActionTypes = function createApiActionTypes(apiName, url) {
  var apiOptions = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  if (!apiName) {
    throw new Error('API Name is missing');
  }

  return {
    request: {
      type: API_REQUEST + '_' + apiName,
      meta: { apiName: apiName, url: url, type: API_REQUEST, apiOptions: apiOptions }
    },
    success: {
      type: API_SUCCESS + '_' + apiName,
      meta: { apiName: apiName, url: url, type: API_SUCCESS, apiOptions: apiOptions }
    },
    failure: {
      type: API_FAILURE + '_' + apiName,
      meta: { apiName: apiName, url: url, type: API_FAILURE, apiOptions: apiOptions }
    }
  };
};

var createApiActions = function createApiActions(apiName, _ref) {
  var url = _ref.url,
      _ref$method = _ref.method,
      method = _ref$method === undefined ? 'GET' : _ref$method,
      _ref$body = _ref.body,
      body = _ref$body === undefined ? undefined : _ref$body,
      _ref$actionTypeOverri = _ref.actionTypeOverrides,
      actionTypeOverrides = _ref$actionTypeOverri === undefined ? {} : _ref$actionTypeOverri,
      _ref$apiOptions = _ref.apiOptions,
      apiOptions = _ref$apiOptions === undefined ? {} : _ref$apiOptions;

  if (!apiName) {
    throw new Error('API Name is missing');
  }

  var actionTypes = deepMerge(createApiActionTypes(apiName, url, apiOptions), actionTypeOverrides);

  return _defineProperty({}, _reduxApiMiddleware.RSAA, {
    method: method,
    body: body,
    endpoint: url,
    credentials: 'include',
    options: {
      redirect: 'follow'
    },
    headers: {
      'Content-Type': 'application/json',
      Accept: 'application/json'
    },
    types: [actionTypes.request, actionTypes.success, actionTypes.failure]
  });
};

exports.default = createApiActions;